@@ -13,8 +13,18 @@
  *   GET /api/health.php?check=all&detailed=1    - All checks with detailed metrics
  *
  * Parameters:
- *   check (optional)    - Type of health check (cpu|connections|disk|swap|docker|all)
- *   detailed (optional) - Set to '1' to include detailed metrics (default: status only)
+ *   check (optional)              - Type of health check (cpu|connections|disk|swap|docker|all)
+ *   detailed (optional)           - Set to '1' to include detailed metrics (default: status only)
+ *
+ *   Threshold Overrides (optional):
+ *   connections_warning (int)     - Override connection warning threshold (default: 200)
+ *   connections_critical (int)    - Override connection critical threshold (default: 400)
+ *   cpu_warning (float)           - Override CPU warning threshold (default: 0.7)
+ *   cpu_critical (float)          - Override CPU critical threshold (default: 1.0)
+ *   disk_warning (int)            - Override disk warning threshold % (default: 80)
+ *   disk_critical (int)           - Override disk critical threshold % (default: 90)
+ *   swap_warning (int)            - Override swap warning threshold % (default: 50)
+ *   swap_critical (int)           - Override swap critical threshold % (default: 80)
  *
  * Rate Limiting: 10 requests per minute per IP address
  *
@@ -25,6 +35,10 @@
  *   {"success": true, "timestamp": "2025-10-09T...", "data": {"status": "healthy", ...}}
  */
 
+// Load health check configuration
+define('WHP', true);
+require_once(__DIR__ . '/../configs/health-check.config.php');
+
 // Simple rate limiting for unauthenticated health check endpoint
 // Allows 10 requests per minute per IP address
 $clientIP = $_SERVER['REMOTE_ADDR'] ?? 'unknown';
@@ -95,6 +109,9 @@ $check = strtolower(trim($check));
 // Get detailed parameter (defaults to false for security)
 $detailed = isset($_GET['detailed']) && $_GET['detailed'] === '1';
 
+// Parse threshold overrides from URL parameters
+$thresholds = parseThresholdOverrides();
+
 // Whitelist validation
 $allowed_checks = ['cpu', 'connections', 'disk', 'swap', 'docker', 'all'];
 if (!in_array($check, $allowed_checks, true)) {
@@ -109,19 +126,19 @@ if (!in_array($check, $allowed_checks, true)) {
 try {
     switch ($check) {
         case 'cpu':
-            $result = getCpuLoad($detailed);
+            $result = getCpuLoad($detailed, $thresholds);
             break;
 
         case 'connections':
-            $result = getConnectionCount($detailed);
+            $result = getConnectionCount($detailed, $thresholds);
             break;
 
         case 'disk':
-            $result = getDiskUsage($detailed);
+            $result = getDiskUsage($detailed, $thresholds);
             break;
 
         case 'swap':
-            $result = getSwapUsage($detailed);
+            $result = getSwapUsage($detailed, $thresholds);
             break;
 
         case 'docker':
@@ -129,7 +146,7 @@ try {
             break;
 
         case 'all':
-            $result = getAllHealthChecks($detailed);
+            $result = getAllHealthChecks($detailed, $thresholds);
             break;
 
         default:
@@ -160,12 +177,88 @@ try {
 
 exit(0);
 
+/**
+ * Parse and validate threshold overrides from URL parameters
+ * @return array Validated threshold values
+ */
+function parseThresholdOverrides() {
+    $thresholds = [
+        'connections_warning' => HEALTH_CHECK_CONNECTIONS_WARNING_DEFAULT,
+        'connections_critical' => HEALTH_CHECK_CONNECTIONS_CRITICAL_DEFAULT,
+        'cpu_warning' => HEALTH_CHECK_CPU_WARNING_DEFAULT,
+        'cpu_critical' => HEALTH_CHECK_CPU_CRITICAL_DEFAULT,
+        'disk_warning' => HEALTH_CHECK_DISK_WARNING_DEFAULT,
+        'disk_critical' => HEALTH_CHECK_DISK_CRITICAL_DEFAULT,
+        'swap_warning' => HEALTH_CHECK_SWAP_WARNING_DEFAULT,
+        'swap_critical' => HEALTH_CHECK_SWAP_CRITICAL_DEFAULT
+    ];
+
+    // Connection thresholds (positive integers)
+    if (isset($_GET['connections_warning'])) {
+        $value = filter_var($_GET['connections_warning'], FILTER_VALIDATE_INT);
+        if ($value !== false && $value > 0 && $value < 10000) {
+            $thresholds['connections_warning'] = $value;
+        }
+    }
+    if (isset($_GET['connections_critical'])) {
+        $value = filter_var($_GET['connections_critical'], FILTER_VALIDATE_INT);
+        if ($value !== false && $value > 0 && $value < 10000) {
+            $thresholds['connections_critical'] = $value;
+        }
+    }
+
+    // CPU thresholds (positive floats)
+    if (isset($_GET['cpu_warning'])) {
+        $value = filter_var($_GET['cpu_warning'], FILTER_VALIDATE_FLOAT);
+        if ($value !== false && $value > 0 && $value < 100) {
+            $thresholds['cpu_warning'] = $value;
+        }
+    }
+    if (isset($_GET['cpu_critical'])) {
+        $value = filter_var($_GET['cpu_critical'], FILTER_VALIDATE_FLOAT);
+        if ($value !== false && $value > 0 && $value < 100) {
+            $thresholds['cpu_critical'] = $value;
+        }
+    }
+
+    // Disk thresholds (percentage 1-100)
+    if (isset($_GET['disk_warning'])) {
+        $value = filter_var($_GET['disk_warning'], FILTER_VALIDATE_INT);
+        if ($value !== false && $value > 0 && $value <= 100) {
+            $thresholds['disk_warning'] = $value;
+        }
+    }
+    if (isset($_GET['disk_critical'])) {
+        $value = filter_var($_GET['disk_critical'], FILTER_VALIDATE_INT);
+        if ($value !== false && $value > 0 && $value <= 100) {
+            $thresholds['disk_critical'] = $value;
+        }
+    }
+
+    // Swap thresholds (percentage 1-100)
+    if (isset($_GET['swap_warning'])) {
+        $value = filter_var($_GET['swap_warning'], FILTER_VALIDATE_INT);
+        if ($value !== false && $value > 0 && $value <= 100) {
+            $thresholds['swap_warning'] = $value;
+        }
+    }
+    if (isset($_GET['swap_critical'])) {
+        $value = filter_var($_GET['swap_critical'], FILTER_VALIDATE_INT);
+        if ($value !== false && $value > 0 && $value <= 100) {
+            $thresholds['swap_critical'] = $value;
+        }
+    }
+
+    return $thresholds;
+}
+
 /**
  * Get CPU load average
  * @param bool $detailed Whether to include detailed metrics
+ * @param array $thresholds Threshold overrides
  * @return array CPU load statistics
  */
-function getCpuLoad($detailed = false) {
+function getCpuLoad($detailed = false, $thresholds = []) {
     $loadavg = @file_get_contents('/proc/loadavg');
 
     if ($loadavg === false) {
@@ -190,10 +283,14 @@ function getCpuLoad($detailed = false) {
     // Calculate load per core
     $loadPerCore = $load1min / $cpuCores;
 
+    // Get threshold values
+    $warningThreshold = $thresholds['cpu_warning'] ?? HEALTH_CHECK_CPU_WARNING_DEFAULT;
+    $criticalThreshold = $thresholds['cpu_critical'] ?? HEALTH_CHECK_CPU_CRITICAL_DEFAULT;
+
     // Determine status based on load per core
-    if ($loadPerCore < 0.7) {
+    if ($loadPerCore < $warningThreshold) {
         $status = 'healthy';
-    } elseif ($loadPerCore < 1.0) {
+    } elseif ($loadPerCore < $criticalThreshold) {
         $status = 'warning';
     } else {
         $status = 'critical';
@@ -223,9 +320,10 @@ function getCpuLoad($detailed = false) {
 /**
  * Get HTTP/HTTPS connection count
  * @param bool $detailed Whether to include detailed metrics
+ * @param array $thresholds Threshold overrides
  * @return array Connection statistics for ports 80 and 443
  */
-function getConnectionCount($detailed = false) {
+function getConnectionCount($detailed = false, $thresholds = []) {
     // Get unique client connections from HAProxy container
     // This counts unique IP addresses connected to ports 80 and 443
     $output = @shell_exec('docker exec haproxy-manager netstat -plan 2>/dev/null | grep -E "(:443|:80)" | awk -F " " \'{print $5}\' | awk -F ":" \'{print $1}\' | grep -v "0.0.0.0" | grep -v "::" | sort -u | wc -l');
@@ -256,13 +354,16 @@ function getConnectionCount($detailed = false) {
         $totalConnections = $connections80 + $connections443;
     }
 
+    // Get threshold values
+    $warningThreshold = $thresholds['connections_warning'] ?? HEALTH_CHECK_CONNECTIONS_WARNING_DEFAULT;
+    $criticalThreshold = $thresholds['connections_critical'] ?? HEALTH_CHECK_CONNECTIONS_CRITICAL_DEFAULT;
+
     // Determine status based on unique client connections
     // Thresholds are for unique clients, not total connections
-    // Higher thresholds for shared hosting server
     $status = 'healthy';
-    if ($uniqueClients >= 400) {
+    if ($uniqueClients >= $criticalThreshold) {
         $status = 'critical';
-    } elseif ($uniqueClients >= 200) {
+    } elseif ($uniqueClients >= $warningThreshold) {
         $status = 'warning';
     }
 
@@ -285,14 +386,19 @@ function getConnectionCount($detailed = false) {
 /**
  * Get disk usage statistics
  * @param bool $detailed Whether to include detailed metrics
+ * @param array $thresholds Threshold overrides
  * @return array Disk usage information
  */
-function getDiskUsage($detailed = false) {
+function getDiskUsage($detailed = false, $thresholds = []) {
     $rootFree = @disk_free_space('/');
     $rootTotal = @disk_total_space('/');
     $dockerFree = @disk_free_space('/docker');
     $dockerTotal = @disk_total_space('/docker');
 
+    // Get threshold values
+    $warningThreshold = $thresholds['disk_warning'] ?? HEALTH_CHECK_DISK_WARNING_DEFAULT;
+    $criticalThreshold = $thresholds['disk_critical'] ?? HEALTH_CHECK_DISK_CRITICAL_DEFAULT;
+
     $filesystems = [];
     $overallStatus = 'healthy';
 
@@ -302,10 +408,10 @@ function getDiskUsage($detailed = false) {
         $rootUsagePercent = ($rootUsed / $rootTotal) * 100;
 
         $rootStatus = 'healthy';
-        if ($rootUsagePercent >= 90) {
+        if ($rootUsagePercent >= $criticalThreshold) {
             $rootStatus = 'critical';
             $overallStatus = 'critical';
-        } elseif ($rootUsagePercent >= 80) {
+        } elseif ($rootUsagePercent >= $warningThreshold) {
             $rootStatus = 'warning';
             if ($overallStatus === 'healthy') {
                 $overallStatus = 'warning';
@@ -329,10 +435,10 @@ function getDiskUsage($detailed = false) {
         $dockerUsagePercent = ($dockerUsed / $dockerTotal) * 100;
 
         $dockerStatus = 'healthy';
-        if ($dockerUsagePercent >= 90) {
+        if ($dockerUsagePercent >= $criticalThreshold) {
             $dockerStatus = 'critical';
             $overallStatus = 'critical';
-        } elseif ($dockerUsagePercent >= 80) {
+        } elseif ($dockerUsagePercent >= $warningThreshold) {
             $dockerStatus = 'warning';
             if ($overallStatus === 'healthy') {
                 $overallStatus = 'warning';
@@ -362,9 +468,10 @@ function getDiskUsage($detailed = false) {
 /**
  * Get swap usage statistics
  * @param bool $detailed Whether to include detailed metrics
+ * @param array $thresholds Threshold overrides
  * @return array Swap usage information
  */
-function getSwapUsage($detailed = false) {
+function getSwapUsage($detailed = false, $thresholds = []) {
     $meminfo = @file_get_contents('/proc/meminfo');
 
     if ($meminfo === false) {
@@ -397,12 +504,16 @@ function getSwapUsage($detailed = false) {
     $swapUsed = $swapTotal - $swapFree;
     $swapUsagePercent = ($swapUsed / $swapTotal) * 100;
 
+    // Get threshold values
+    $warningThreshold = $thresholds['swap_warning'] ?? HEALTH_CHECK_SWAP_WARNING_DEFAULT;
+    $criticalThreshold = $thresholds['swap_critical'] ?? HEALTH_CHECK_SWAP_CRITICAL_DEFAULT;
+
     // Determine status based on swap usage
     // High swap usage indicates memory pressure
     $status = 'healthy';
-    if ($swapUsagePercent >= 80) {
+    if ($swapUsagePercent >= $criticalThreshold) {
         $status = 'critical';
-    } elseif ($swapUsagePercent >= 50) {
+    } elseif ($swapUsagePercent >= $warningThreshold) {
         $status = 'warning';
     }
 
@@ -480,13 +591,14 @@ function getDockerStatus($detailed = false) {
 /**
  * Get all health checks
  * @param bool $detailed Whether to include detailed metrics
+ * @param array $thresholds Threshold overrides
  * @return array Combined health check results
  */
-function getAllHealthChecks($detailed = false) {
-    $cpu = getCpuLoad($detailed);
-    $connections = getConnectionCount($detailed);
-    $disk = getDiskUsage($detailed);
-    $swap = getSwapUsage($detailed);
+function getAllHealthChecks($detailed = false, $thresholds = []) {
+    $cpu = getCpuLoad($detailed, $thresholds);
+    $connections = getConnectionCount($detailed, $thresholds);
+    $disk = getDiskUsage($detailed, $thresholds);
+    $swap = getSwapUsage($detailed, $thresholds);
     $docker = getDockerStatus($detailed);
 
     // Determine overall status
